==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QDispatchCompute.java <==
package io.qt.qt3d.render;


/**
 * <p>FrameGraph node to issue work for the compute shader on GPU</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html">Qt3DRender::QDispatchCompute</a></p>
 */
public class QDispatchCompute extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDispatchCompute.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupX-prop">Qt3DRender::QDispatchCompute::workGroupXChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupX")
    public final Signal0 workGroupXChanged = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupY-prop">Qt3DRender::QDispatchCompute::workGroupYChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupY")
    public final Signal0 workGroupYChanged = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupZ-prop">Qt3DRender::QDispatchCompute::workGroupZChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupZ")
    public final Signal0 workGroupZChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QDispatchCompute(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDispatchCompute() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#QDispatchCompute">Qt3DRender::QDispatchCompute::QDispatchCompute(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QDispatchCompute(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDispatchCompute instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupX-prop">Qt3DRender::QDispatchCompute::setWorkGroupX(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupX")
    public final void setWorkGroupX(int workGroupX){
        setWorkGroupX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupX);
    }
    
    private native void setWorkGroupX_native_int(long __this__nativeId, int workGroupX);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupY-prop">Qt3DRender::QDispatchCompute::setWorkGroupY(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupY")
    public final void setWorkGroupY(int workGroupY){
        setWorkGroupY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupY);
    }
    
    private native void setWorkGroupY_native_int(long __this__nativeId, int workGroupY);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupZ-prop">Qt3DRender::QDispatchCompute::setWorkGroupZ(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupZ")
    public final void setWorkGroupZ(int workGroupZ){
        setWorkGroupZ_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupZ);
    }
    
    private native void setWorkGroupZ_native_int(long __this__nativeId, int workGroupZ);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupX-prop">Qt3DRender::QDispatchCompute::workGroupX()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupX")
    @io.qt.QtUninvokable
    public final int workGroupX(){
        return workGroupX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupY-prop">Qt3DRender::QDispatchCompute::workGroupY()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupY")
    @io.qt.QtUninvokable
    public final int workGroupY(){
        return workGroupY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qdispatchcompute.html#workGroupZ-prop">Qt3DRender::QDispatchCompute::workGroupZ()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupZ")
    @io.qt.QtUninvokable
    public final int workGroupZ(){
        return workGroupZ_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupZ_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDispatchCompute(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDispatchCompute(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDispatchCompute instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.3.3-sources.jar: io/qt/qt3d/render/QDispatchCompute.java <==
package io.qt.qt3d.render;


/**
 * <p>FrameGraph node to issue work for the compute shader on GPU</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html">Qt3DRender::QDispatchCompute</a></p>
 */
public class QDispatchCompute extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDispatchCompute.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupX-prop">Qt3DRender::QDispatchCompute::workGroupXChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupX")
    public final Signal0 workGroupXChanged = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupY-prop">Qt3DRender::QDispatchCompute::workGroupYChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupY")
    public final Signal0 workGroupYChanged = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupZ-prop">Qt3DRender::QDispatchCompute::workGroupZChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupZ")
    public final Signal0 workGroupZChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QDispatchCompute(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDispatchCompute() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#QDispatchCompute">Qt3DRender::QDispatchCompute::QDispatchCompute(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QDispatchCompute(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDispatchCompute instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupX-prop">Qt3DRender::QDispatchCompute::setWorkGroupX(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupX")
    public final void setWorkGroupX(int workGroupX){
        setWorkGroupX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupX);
    }
    
    private native void setWorkGroupX_native_int(long __this__nativeId, int workGroupX);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupY-prop">Qt3DRender::QDispatchCompute::setWorkGroupY(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupY")
    public final void setWorkGroupY(int workGroupY){
        setWorkGroupY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupY);
    }
    
    private native void setWorkGroupY_native_int(long __this__nativeId, int workGroupY);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupZ-prop">Qt3DRender::QDispatchCompute::setWorkGroupZ(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupZ")
    public final void setWorkGroupZ(int workGroupZ){
        setWorkGroupZ_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupZ);
    }
    
    private native void setWorkGroupZ_native_int(long __this__nativeId, int workGroupZ);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupX-prop">Qt3DRender::QDispatchCompute::workGroupX()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupX")
    @io.qt.QtUninvokable
    public final int workGroupX(){
        return workGroupX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupY-prop">Qt3DRender::QDispatchCompute::workGroupY()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupY")
    @io.qt.QtUninvokable
    public final int workGroupY(){
        return workGroupY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdispatchcompute.html#workGroupZ-prop">Qt3DRender::QDispatchCompute::workGroupZ()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupZ")
    @io.qt.QtUninvokable
    public final int workGroupZ(){
        return workGroupZ_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupZ_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDispatchCompute(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDispatchCompute(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDispatchCompute instance, QDeclarativeConstructor constructor);
    
}
